#ifndef R_NO_REMAP
#define R_NO_REMAP
#endif
#ifndef __cbindThetaOmega_H__
#define __cbindThetaOmega_H__
#if defined(__cplusplus)

List cbindThetaOmega(RObject inputParametersRO, List& individualParameters);
extern "C" {
#endif

#if defined(__cplusplus)
}
#endif
#endif
